@@ -1,3 +1,3 @@
 const config = {};
-config.API_URL = 'ADD_YOUR_URL';
+config.API_URL = 'http://localhost:9000';
 export default config;
